@@ -91,6 +91,7 @@ define_keywords!(
     ALERT,
     ALGORITHM,
     ALIAS,
+    ALIGNMENT,
     ALL,
     ALLOCATE,
     ALLOWOVERWRITE,
@@ -119,6 +120,7 @@ define_keywords!(
     AUDIT,
     AUTHENTICATION,
     AUTHORIZATION,
+    AUTHORIZATIONS,
     AUTO,
     AUTOEXTEND_SIZE,
     AUTOINCREMENT,
@@ -165,6 +167,7 @@ define_keywords!(
     CACHE,
     CALL,
     CALLED,
+    CANONICAL,
     CARDINALITY,
     CASCADE,
     CASCADED,
@@ -176,6 +179,7 @@ define_keywords!(
     CATALOG_SYNC_NAMESPACE_FLATTEN_DELIMITER,
     CATALOG_SYNC_NAMESPACE_MODE,
     CATCH,
+    CATEGORY,
     CEIL,
     CEILING,
     CENTURY,
@@ -193,6 +197,7 @@ define_keywords!(
     CHECK,
     CHECKSUM,
     CIRCLE,
+    CLASS,
     CLEANPATH,
     CLEAR,
     CLOB,
@@ -202,6 +207,7 @@ define_keywords!(
     CLUSTERED,
     CLUSTERING,
     COALESCE,
+    COLLATABLE,
     COLLATE,
     COLLATION,
     COLLECT,
@@ -212,8 +218,11 @@ define_keywords!(
     COMMENT,
     COMMIT,
     COMMITTED,
+    COMMUTATOR,
     COMPATIBLE,
+    COMPRESS,
     COMPRESSION,
+    COMPUPDATE,
     COMPUTE,
     CONCURRENTLY,
     CONDITION,
@@ -279,6 +288,8 @@ define_keywords!(
     DEFAULT,
     DEFAULTS,
     DEFAULT_DDL_COLLATION,
+    DEFAULT_MFA_METHOD,
+    DEFAULT_SECONDARY_ROLES,
     DEFERRABLE,
     DEFERRED,
     DEFINE,
@@ -286,6 +297,7 @@ define_keywords!(
     DEFINER,
     DELAYED,
     DELAY_KEY_WRITE,
+    DELEGATED,
     DELETE,
     DELIMITED,
     DELIMITER,
@@ -314,6 +326,7 @@ define_keywords!(
     DOY,
     DROP,
     DRY,
+    DUO,
     DUPLICATE,
     DYNAMIC,
     EACH,
@@ -336,6 +349,7 @@ define_keywords!(
     ENFORCED,
     ENGINE,
     ENGINE_ATTRIBUTE,
+    ENROLL,
     ENUM,
     ENUM16,
     ENUM8,
@@ -374,6 +388,7 @@ define_keywords!(
     FAIL,
     FAILOVER,
     FALSE,
+    FAMILY,
     FETCH,
     FIELDS,
     FILE,
@@ -435,6 +450,7 @@ define_keywords!(
     GROUPS,
     GZIP,
     HASH,
+    HASHES,
     HAVING,
     HEADER,
     HEAP,
@@ -449,6 +465,7 @@ define_keywords!(
     IAM_ROLE,
     ICEBERG,
     ID,
+    IDENTIFIED,
     IDENTITY,
     IDENTITY_INSERT,
     IF,
@@ -494,11 +511,13 @@ define_keywords!(
     INT8,
     INTEGER,
     INTEGRATION,
+    INTERNALLENGTH,
     INTERPOLATE,
     INTERSECT,
     INTERSECTION,
     INTERVAL,
     INTO,
+    INVISIBLE,
     INVOKER,
     IO,
     IS,
@@ -526,7 +545,10 @@ define_keywords!(
     LATERAL,
     LEAD,
     LEADING,
+    LEAKPROOF,
+    LEAST,
     LEFT,
+    LEFTARG,
     LEVEL,
     LIKE,
     LIKE_REGEX,
@@ -547,6 +569,7 @@ define_keywords!(
     LOG,
     LOGIN,
     LOGS,
+    LONG,
     LONGBLOB,
     LONGTEXT,
     LOWCARDINALITY,
@@ -555,6 +578,7 @@ define_keywords!(
     LS,
     LSEG,
     MACRO,
+    MAIN,
     MANAGE,
     MANAGED,
     MANAGEDLOCATION,
@@ -580,11 +604,13 @@ define_keywords!(
     MEDIUMTEXT,
     MEMBER,
     MERGE,
+    MERGES,
     MESSAGE,
     METADATA,
     METHOD,
     METRIC,
     METRICS,
+    MFA,
     MICROSECOND,
     MICROSECONDS,
     MILLENIUM,
@@ -606,6 +632,7 @@ define_keywords!(
     MONTH,
     MONTHS,
     MSCK,
+    MULTIRANGE_TYPE_NAME,
     MULTISET,
     MUTATION,
     NAME,
@@ -616,6 +643,7 @@ define_keywords!(
     NATURAL,
     NCHAR,
     NCLOB,
+    NEGATOR,
     NEST,
     NESTED,
     NETWORK,
@@ -627,6 +655,7 @@ define_keywords!(
     NFKD,
     NO,
     NOBYPASSRLS,
+    NOCOMPRESS,
     NOCREATEDB,
     NOCREATEROLE,
     NOINHERIT,
@@ -650,6 +679,7 @@ define_keywords!(
     NULLABLE,
     NULLIF,
     NULLS,
+    NUMBER,
     NUMERIC,
     NVARCHAR,
     OBJECT,
@@ -684,6 +714,7 @@ define_keywords!(
     ORDINALITY,
     ORGANIZATION,
     OTHER,
+    OTP,
     OUT,
     OUTER,
     OUTPUT,
@@ -704,14 +735,18 @@ define_keywords!(
     PARAMETER,
     PARQUET,
     PART,
+    PARTIAL,
     PARTITION,
     PARTITIONED,
     PARTITIONS,
+    PASSEDBYVALUE,
     PASSING,
+    PASSKEY,
     PASSWORD,
     PAST,
     PATH,
     PATTERN,
+    PCTFREE,
     PER,
     PERCENT,
     PERCENTILE_CONT,
@@ -722,6 +757,7 @@ define_keywords!(
     PERSISTENT,
     PIVOT,
     PLACING,
+    PLAIN,
     PLAN,
     PLANS,
     POINT,
@@ -736,8 +772,10 @@ define_keywords!(
     PRECEDES,
     PRECEDING,
     PRECISION,
+    PREFERRED,
     PREPARE,
     PRESERVE,
+    PRESET,
     PREWHERE,
     PRIMARY,
     PRINT,
@@ -752,6 +790,7 @@ define_keywords!(
     PURGE,
     QUALIFY,
     QUARTER,
+    QUERIES,
     QUERY,
     QUOTE,
     RAISE,
@@ -764,11 +803,13 @@ define_keywords!(
     READS,
     READ_ONLY,
     REAL,
+    RECEIVE,
     RECLUSTER,
     RECURSIVE,
     REF,
     REFERENCES,
     REFERENCING,
+    REFRESH,
     REFRESH_MODE,
     REGCLASS,
     REGEXP,
@@ -789,6 +830,7 @@ define_keywords!(
     RELEASES,
     REMOTE,
     REMOVE,
+    REMOVEQUOTES,
     RENAME,
     REORG,
     REPAIR,
@@ -817,6 +859,7 @@ define_keywords!(
     RETURNS,
     REVOKE,
     RIGHT,
+    RIGHTARG,
     RLIKE,
     RM,
     ROLE,
@@ -852,6 +895,7 @@ define_keywords!(
     SELECT,
     SEMANTIC_VIEW,
     SEMI,
+    SEND,
     SENSITIVE,
     SEPARATOR,
     SEQUENCE,
@@ -874,6 +918,8 @@ define_keywords!(
     SHOW,
     SIGNED,
     SIMILAR,
+    SIMPLE,
+    SIZE,
     SKIP,
     SLOW,
     SMALLINT,
@@ -902,6 +948,7 @@ define_keywords!(
     STATS_AUTO_RECALC,
     STATS_PERSISTENT,
     STATS_SAMPLE_PAGES,
+    STATUPDATE,
     STATUS,
     STDDEV_POP,
     STDDEV_SAMP,
@@ -918,9 +965,13 @@ define_keywords!(
     STRING,
     STRUCT,
     SUBMULTISET,
+    SUBSCRIPT,
     SUBSTR,
     SUBSTRING,
     SUBSTRING_REGEX,
+    SUBTYPE,
+    SUBTYPE_DIFF,
+    SUBTYPE_OPCLASS,
     SUCCEEDS,
     SUM,
     SUPER,
@@ -930,6 +981,7 @@ define_keywords!(
     SWAP,
     SYMMETRIC,
     SYNC,
+    SYNONYM,
     SYSTEM,
     SYSTEM_TIME,
     SYSTEM_USER,
@@ -968,6 +1020,7 @@ define_keywords!(
     TO,
     TOP,
     TOTALS,
+    TOTP,
     TRACE,
     TRAILING,
     TRANSACTION,
@@ -989,6 +1042,8 @@ define_keywords!(
     TSVECTOR,
     TUPLE,
     TYPE,
+    TYPMOD_IN,
+    TYPMOD_OUT,
     UBIGINT,
     UESCAPE,
     UHUGEINT,
@@ -1038,6 +1093,8 @@ define_keywords!(
     VARBINARY,
     VARBIT,
     VARCHAR,
+    VARCHAR2,
+    VARIABLE,
     VARIABLES,
     VARYING,
     VAR_POP,
@@ -1066,6 +1123,7 @@ define_keywords!(
     WITHOUT,
     WITHOUT_ARRAY_WRAPPER,
     WORK,
+    WORKLOAD_IDENTITY,
     WRAPPER,
     WRITE,
     XML,
