@@ -291,6 +291,7 @@ pub fn all_dialects() -> TestedDialects {
         Box::new(DuckDbDialect {}),
         Box::new(DatabricksDialect {}),
         Box::new(ClickHouseDialect {}),
+        Box::new(OracleDialect {}),
     ])
 }
 
@@ -343,21 +344,12 @@ pub fn expr_from_projection(item: &SelectItem) -> &Expr {
 
 pub fn alter_table_op_with_name(stmt: Statement, expected_name: &str) -> AlterTableOperation {
     match stmt {
-        Statement::AlterTable {
-            name,
-            if_exists,
-            only: is_only,
-            operations,
-            on_cluster: _,
-            location: _,
-            iceberg,
-            end_token: _,
-        } => {
-            assert_eq!(name.to_string(), expected_name);
-            assert!(!if_exists);
-            assert!(!is_only);
-            assert!(!iceberg);
-            only(operations)
+        Statement::AlterTable(alter_table) => {
+            assert_eq!(alter_table.name.to_string(), expected_name);
+            assert!(!alter_table.if_exists);
+            assert!(!alter_table.only);
+            assert_eq!(alter_table.table_type, None);
+            only(alter_table.operations)
         }
         _ => panic!("Expected ALTER TABLE statement"),
     }
@@ -377,8 +369,9 @@ pub fn single_quoted_string(s: impl Into<String>) -> Value {
     Value::SingleQuotedString(s.into())
 }
 
-pub fn table_alias(name: impl Into<String>) -> Option<TableAlias> {
+pub fn table_alias(explicit: bool, name: impl Into<String>) -> Option<TableAlias> {
     Some(TableAlias {
+        explicit,
         name: Ident::new(name),
         columns: vec![],
     })
@@ -414,13 +407,14 @@ pub fn table_from_name(name: ObjectName) -> TableFactor {
     }
 }
 
-pub fn table_with_alias(name: impl Into<String>, alias: impl Into<String>) -> TableFactor {
+pub fn table_with_alias(
+    name: impl Into<String>,
+    with_as_keyword: bool,
+    alias: impl Into<String>,
+) -> TableFactor {
     TableFactor::Table {
         name: ObjectName::from(vec![Ident::new(name)]),
-        alias: Some(TableAlias {
-            name: Ident::new(alias),
-            columns: vec![],
-        }),
+        alias: table_alias(with_as_keyword, alias),
         args: None,
         with_hints: vec![],
         version: None,
@@ -469,37 +463,36 @@ pub fn index_column(stmt: Statement) -> Expr {
         }
         Statement::CreateTable(CreateTable { constraints, .. }) => {
             match constraints.first().unwrap() {
-                TableConstraint::Index { columns, .. } => {
-                    columns.first().unwrap().column.expr.clone()
+                TableConstraint::Index(constraint) => {
+                    constraint.columns.first().unwrap().column.expr.clone()
                 }
-                TableConstraint::Unique { columns, .. } => {
-                    columns.first().unwrap().column.expr.clone()
+                TableConstraint::Unique(constraint) => {
+                    constraint.columns.first().unwrap().column.expr.clone()
                 }
-                TableConstraint::PrimaryKey { columns, .. } => {
-                    columns.first().unwrap().column.expr.clone()
+                TableConstraint::PrimaryKey(constraint) => {
+                    constraint.columns.first().unwrap().column.expr.clone()
                 }
-                TableConstraint::FulltextOrSpatial { columns, .. } => {
-                    columns.first().unwrap().column.expr.clone()
+                TableConstraint::FulltextOrSpatial(constraint) => {
+                    constraint.columns.first().unwrap().column.expr.clone()
                 }
                 _ => panic!("Expected an index, unique, primary, full text, or spatial constraint (foreign key does not support general key part expressions)"),
             }
         }
-        Statement::AlterTable { operations, .. } => match operations.first().unwrap() {
+        Statement::AlterTable(alter_table) => match alter_table.operations.first().unwrap() {
             AlterTableOperation::AddConstraint { constraint, .. } => {
                 match constraint {
-                    TableConstraint::Index { columns, .. } => {
-                        columns.first().unwrap().column.expr.clone()
+                    TableConstraint::Index(constraint) => {
+                        constraint.columns.first().unwrap().column.expr.clone()
                     }
-                    TableConstraint::Unique { columns, .. } => {
-                        columns.first().unwrap().column.expr.clone()
+                    TableConstraint::Unique(constraint) => {
+                        constraint.columns.first().unwrap().column.expr.clone()
                     }
-                    TableConstraint::PrimaryKey { columns, .. } => {
-                        columns.first().unwrap().column.expr.clone()
+                    TableConstraint::PrimaryKey(constraint) => {
+                        constraint.columns.first().unwrap().column.expr.clone()
+                    }
+                    TableConstraint::FulltextOrSpatial(constraint) => {
+                        constraint.columns.first().unwrap().column.expr.clone()
                     }
-                    TableConstraint::FulltextOrSpatial {
-                        columns,
-                        ..
-                    } => columns.first().unwrap().column.expr.clone(),
                     _ => panic!("Expected an index, unique, primary, full text, or spatial constraint (foreign key does not support general key part expressions)"),
                 }
             }
