@@ -408,10 +408,13 @@ fn parse_create_function() {
             assert_eq!(name.to_string(), "mydb.myfunc");
             assert_eq!(
                 function_body,
-                Some(CreateFunctionBody::AsBeforeOptions(Expr::Value(
-                    (Value::SingleQuotedString("org.random.class.Name".to_string()))
-                        .with_empty_span()
-                )))
+                Some(CreateFunctionBody::AsBeforeOptions {
+                    body: Expr::Value(
+                        (Value::SingleQuotedString("org.random.class.Name".to_string()))
+                            .with_empty_span()
+                    ),
+                    link_symbol: None,
+                })
             );
             assert_eq!(
                 using,
