@@ -92,10 +92,31 @@ fn parse_mssql_single_quoted_aliases() {
 
 #[test]
 fn parse_mssql_delimited_identifiers() {
-    let _ = ms().one_statement_parses_to(
+    let s = ms().one_statement_parses_to(
         "SELECT [a.b!] [FROM] FROM foo [WHERE]",
-        "SELECT [a.b!] AS [FROM] FROM foo AS [WHERE]",
+        "SELECT [a.b!] AS [FROM] FROM foo [WHERE]",
     );
+    if let Statement::Query(q) = s {
+        match &q.body.as_select().expect("not a SELECT").from[..] {
+            [from] => match &from.relation {
+                TableFactor::Table { name, alias, .. } => {
+                    assert_eq!(&format!("{name}"), "foo");
+                    assert_eq!(
+                        alias,
+                        &Some(TableAlias {
+                            explicit: false,
+                            name: Ident::with_quote('[', "WHERE"),
+                            columns: vec![]
+                        })
+                    );
+                }
+                _ => panic!("unexpected FROM type"),
+            },
+            _ => panic!("unexpected number of FROMs"),
+        }
+    } else {
+        panic!("statement not parsed as QUERY");
+    }
 }
 
 #[test]
@@ -156,6 +177,7 @@ fn parse_create_procedure() {
                     },
                     data_type: DataType::Int(None),
                     mode: None,
+                    default: None,
                 },
                 ProcedureParam {
                     name: Ident {
@@ -168,6 +190,7 @@ fn parse_create_procedure() {
                         unit: None
                     })),
                     mode: None,
+                    default: None,
                 }
             ]),
             name: ObjectName::from(vec![Ident {
@@ -196,6 +219,10 @@ fn parse_mssql_create_procedure() {
     let _ = ms().verified_stmt("CREATE PROCEDURE [foo] AS BEGIN SELECT [foo], CASE WHEN [foo] IS NULL THEN 'empty' ELSE 'notempty' END AS [foo]; END");
     // Multiple statements
     let _ = ms().verified_stmt("CREATE PROCEDURE [foo] AS BEGIN UPDATE bar SET col = 'test'; SELECT [foo] FROM BAR WHERE [FOO] > 10; END");
+
+    // parameters with default values
+    let sql = r#"CREATE PROCEDURE foo (IN @a INTEGER = 1, OUT @b TEXT = '2', INOUT @c DATETIME = NULL, @d BOOL = 0) AS BEGIN SELECT 1; END"#;
+    let _ = ms().verified_stmt(sql);
 }
 
 #[test]
@@ -448,10 +475,7 @@ fn parse_mssql_openjson() {
         vec![TableWithJoins {
             relation: TableFactor::Table {
                 name: ObjectName::from(vec![Ident::new("t_test_table")]),
-                alias: Some(TableAlias {
-                    name: Ident::new("A"),
-                    columns: vec![]
-                }),
+                alias: table_alias(true, "A"),
                 args: None,
                 with_hints: vec![],
                 version: None,
@@ -488,10 +512,7 @@ fn parse_mssql_openjson() {
                             as_json: true
                         }
                     ],
-                    alias: Some(TableAlias {
-                        name: Ident::new("B"),
-                        columns: vec![]
-                    })
+                    alias: table_alias(true, "B")
                 },
                 global: false,
                 join_operator: JoinOperator::CrossApply
@@ -508,10 +529,7 @@ fn parse_mssql_openjson() {
         vec![TableWithJoins {
             relation: TableFactor::Table {
                 name: ObjectName::from(vec![Ident::new("t_test_table"),]),
-                alias: Some(TableAlias {
-                    name: Ident::new("A"),
-                    columns: vec![]
-                }),
+                alias: table_alias(true, "A"),
                 args: None,
                 with_hints: vec![],
                 version: None,
@@ -548,10 +566,7 @@ fn parse_mssql_openjson() {
                             as_json: true
                         }
                     ],
-                    alias: Some(TableAlias {
-                        name: Ident::new("B"),
-                        columns: vec![]
-                    })
+                    alias: table_alias(true, "B")
                 },
                 global: false,
                 join_operator: JoinOperator::CrossApply
@@ -568,10 +583,7 @@ fn parse_mssql_openjson() {
         vec![TableWithJoins {
             relation: TableFactor::Table {
                 name: ObjectName::from(vec![Ident::new("t_test_table")]),
-                alias: Some(TableAlias {
-                    name: Ident::new("A"),
-                    columns: vec![]
-                }),
+                alias: table_alias(true, "A"),
                 args: None,
                 with_hints: vec![],
                 version: None,
@@ -608,10 +620,7 @@ fn parse_mssql_openjson() {
                             as_json: false
                         }
                     ],
-                    alias: Some(TableAlias {
-                        name: Ident::new("B"),
-                        columns: vec![]
-                    })
+                    alias: table_alias(true, "B")
                 },
                 global: false,
                 join_operator: JoinOperator::CrossApply
@@ -628,10 +637,7 @@ fn parse_mssql_openjson() {
         vec![TableWithJoins {
             relation: TableFactor::Table {
                 name: ObjectName::from(vec![Ident::new("t_test_table")]),
-                alias: Some(TableAlias {
-                    name: Ident::new("A"),
-                    columns: vec![]
-                }),
+                alias: table_alias(true, "A"),
                 args: None,
                 with_hints: vec![],
                 version: None,
@@ -648,10 +654,7 @@ fn parse_mssql_openjson() {
                     ),
                     json_path: Some(Value::SingleQuotedString("$.config".into())),
                     columns: vec![],
-                    alias: Some(TableAlias {
-                        name: Ident::new("B"),
-                        columns: vec![]
-                    })
+                    alias: table_alias(true, "B")
                 },
                 global: false,
                 join_operator: JoinOperator::CrossApply
@@ -668,10 +671,7 @@ fn parse_mssql_openjson() {
         vec![TableWithJoins {
             relation: TableFactor::Table {
                 name: ObjectName::from(vec![Ident::new("t_test_table")]),
-                alias: Some(TableAlias {
-                    name: Ident::new("A"),
-                    columns: vec![]
-                }),
+                alias: table_alias(true, "A"),
                 args: None,
                 with_hints: vec![],
                 version: None,
@@ -688,10 +688,7 @@ fn parse_mssql_openjson() {
                     ),
                     json_path: None,
                     columns: vec![],
-                    alias: Some(TableAlias {
-                        name: Ident::new("B"),
-                        columns: vec![]
-                    })
+                    alias: table_alias(true, "B")
                 },
                 global: false,
                 join_operator: JoinOperator::CrossApply
@@ -772,14 +769,10 @@ fn parse_mssql_bin_literal() {
 fn parse_mssql_create_role() {
     let sql = "CREATE ROLE mssql AUTHORIZATION helena";
     match ms().verified_stmt(sql) {
-        Statement::CreateRole {
-            names,
-            authorization_owner,
-            ..
-        } => {
-            assert_eq_vec(&["mssql"], &names);
+        Statement::CreateRole(create_role) => {
+            assert_eq_vec(&["mssql"], &create_role.names);
             assert_eq!(
-                authorization_owner,
+                create_role.authorization_owner,
                 Some(ObjectName::from(vec![Ident {
                     value: "helena".into(),
                     quote_style: None,
@@ -1888,12 +1881,7 @@ fn parse_create_table_with_valid_options() {
                 ],
                 constraints: vec![],
                 hive_distribution: HiveDistributionStyle::NONE,
-                hive_formats: Some(HiveFormat {
-                    row_format: None,
-                    serde_properties: None,
-                    storage: None,
-                    location: None,
-                },),
+                hive_formats: None,
                 file_format: None,
                 location: None,
                 query: None,
@@ -2060,12 +2048,7 @@ fn parse_create_table_with_identity_column() {
                 },],
                 constraints: vec![],
                 hive_distribution: HiveDistributionStyle::NONE,
-                hive_formats: Some(HiveFormat {
-                    row_format: None,
-                    serde_properties: None,
-                    storage: None,
-                    location: None,
-                },),
+                hive_formats: None,
                 file_format: None,
                 location: None,
                 query: None,
@@ -2386,17 +2369,17 @@ fn parse_create_trigger() {
         create_stmt,
         Statement::CreateTrigger(CreateTrigger {
             or_alter: true,
+            temporary: false,
             or_replace: false,
             is_constraint: false,
             name: ObjectName::from(vec![Ident::new("reminder1")]),
-            period: TriggerPeriod::After,
+            period: Some(TriggerPeriod::After),
             period_before_table: false,
             events: vec![TriggerEvent::Insert, TriggerEvent::Update(vec![]),],
             table_name: ObjectName::from(vec![Ident::new("Sales"), Ident::new("Customer")]),
             referenced_table_name: None,
             referencing: vec![],
-            trigger_object: TriggerObject::Statement,
-            include_each: false,
+            trigger_object: None,
             condition: None,
             exec_body: None,
             statements_as: true,
